@@ -3,8 +3,6 @@
 
 __author__ = """David Munechika"""
 __email__ = 'david.munechika@gatech.edu'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
-import visual_auditor.visual_auditor
-import visual_auditor.risk_control
-import visual_auditor.slice_finder
\ No newline at end of file
+import visual_auditor.visual_auditor
\ No newline at end of file
